from ngsolve import *
from netgen.csg import *

spline = SplineCurve2d() # create a 2d spline

# define the control points
pnts = [ (-0.21, 0.45),
         (-0.21, 0.18),
         (-0.4, 0.01),
         (-0.68, 0.01) ]
# define the splines using the control points
segs = [ (0,1), (1,2), (2,3), (3,0)]

# add the points and segments to the spline
for pnt in pnts:
    spline.AddPoint (*pnt)

for seg in segs:
    spline.AddSegment (*seg)

# define extrusion path
path = SplineCurve3d()
path.AddPoint(0,0,10)
path.AddPoint(0,0,-10)
path.AddSegment(0,1)

bot = Plane (Pnt(-1.3,-1.25,0), Vec(0, 0, -1));
top = Plane (Pnt(-1.3,-1.25,0.025), Vec(0, 0, 1));
extr = Extrusion(path, spline, Vec(0,1,0))

geo = CSGeometry()
geo.Add (extr  * bot * top)
geo.Draw()
Redraw()

# generate mesh
mesh = Mesh(geo.GenerateMesh(maxh=0.5))
Draw(mesh)
